<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it_IT">
<context>
    <name>AppearancePage</name>
    <message>
        <location filename="../appearancepage.ui" line="20"/>
        <source>Style:</source>
        <translation>Stile:</translation>
    </message>
    <message>
        <location filename="../appearancepage.ui" line="59"/>
        <source>Preview</source>
        <translation>Anteprima</translation>
    </message>
    <message>
        <location filename="../appearancepage.ui" line="66"/>
        <source>Active palette</source>
        <translation>Colori attivi</translation>
    </message>
    <message>
        <location filename="../appearancepage.ui" line="71"/>
        <source>Inactive palette</source>
        <translation>Colori inattivi</translation>
    </message>
    <message>
        <location filename="../appearancepage.ui" line="76"/>
        <source>Disabled palette</source>
        <translation>Colori disabilitati</translation>
    </message>
    <message>
        <location filename="../appearancepage.ui" line="107"/>
        <source>Palette</source>
        <translation>Colori</translation>
    </message>
    <message>
        <location filename="../appearancepage.ui" line="118"/>
        <location filename="../appearancepage.cpp" line="86"/>
        <source>Default</source>
        <translation>Predefiniti</translation>
    </message>
    <message>
        <location filename="../appearancepage.ui" line="128"/>
        <source>Custom</source>
        <translation>Personalizzati</translation>
    </message>
    <message>
        <location filename="../appearancepage.ui" line="155"/>
        <source>Color scheme:</source>
        <translation>Schema colori:</translation>
    </message>
    <message>
        <location filename="../appearancepage.ui" line="178"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../appearancepage.ui" line="209"/>
        <source>Standard dialogs:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="69"/>
        <source>Create</source>
        <translation>Crea</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="70"/>
        <source>Edit</source>
        <translation>Modifica</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="71"/>
        <source>Create a Copy</source>
        <translation>Crea una copia</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="72"/>
        <source>Rename</source>
        <translation>Rinomina</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="74"/>
        <source>Remove</source>
        <translation>Rimuovi</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="141"/>
        <location filename="../appearancepage.cpp" line="215"/>
        <location filename="../appearancepage.cpp" line="254"/>
        <source>Enter Color Scheme Name</source>
        <translation>Inserisci nome dello schema colori</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="141"/>
        <location filename="../appearancepage.cpp" line="215"/>
        <location filename="../appearancepage.cpp" line="254"/>
        <source>File name:</source>
        <translation>Nome file:</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="150"/>
        <location filename="../appearancepage.cpp" line="226"/>
        <location filename="../appearancepage.cpp" line="234"/>
        <location filename="../appearancepage.cpp" line="264"/>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="150"/>
        <location filename="../appearancepage.cpp" line="226"/>
        <location filename="../appearancepage.cpp" line="264"/>
        <source>The color scheme &quot;%1&quot; already exists</source>
        <translation>Lo schema colori &quot;%1&quot; è già esistente</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="168"/>
        <location filename="../appearancepage.cpp" line="191"/>
        <location filename="../appearancepage.cpp" line="249"/>
        <source>Warning</source>
        <translation>Attenzione</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="168"/>
        <location filename="../appearancepage.cpp" line="191"/>
        <location filename="../appearancepage.cpp" line="249"/>
        <source>The color scheme &quot;%1&quot; is read only</source>
        <translation>Lo schema colori &quot;%1&quot; è in sola lettura</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="196"/>
        <source>Confirm Remove</source>
        <translation>Conferma rimozione</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="197"/>
        <source>Are you sure you want to remove color scheme &quot;%1&quot;?</source>
        <translation>Sei sicuro di voler rimuovere lo schema colori &quot;%1&quot;?</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="217"/>
        <source>%1 (copy)</source>
        <translation>%1 (copia)</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="234"/>
        <source>Unable to copy file</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FontConfigDialog</name>
    <message>
        <location filename="../fontconfigdialog.ui" line="14"/>
        <location filename="../fontconfigdialog.cpp" line="73"/>
        <source>Font Configuration</source>
        <translation>Configurazione caratteri</translation>
    </message>
    <message>
        <location filename="../fontconfigdialog.ui" line="29"/>
        <source>Disable automatic hinting for bold fonts</source>
        <translation>Disabilita hinting automatico per grassetto</translation>
    </message>
    <message>
        <location filename="../fontconfigdialog.ui" line="36"/>
        <source>LCD filter:</source>
        <translation>Filtro LCD:</translation>
    </message>
    <message>
        <location filename="../fontconfigdialog.ui" line="43"/>
        <source>Automatic hinting</source>
        <translation>Hinting automatico</translation>
    </message>
    <message>
        <location filename="../fontconfigdialog.ui" line="50"/>
        <source>Hinting</source>
        <translation>Hinting</translation>
    </message>
    <message>
        <location filename="../fontconfigdialog.ui" line="67"/>
        <source>Font resolution:</source>
        <translation>Risoluzione font:</translation>
    </message>
    <message>
        <location filename="../fontconfigdialog.ui" line="110"/>
        <source> dpi</source>
        <translation> dpi</translation>
    </message>
    <message>
        <location filename="../fontconfigdialog.ui" line="83"/>
        <source>Subpixel geometry:</source>
        <translation>Geometria sub-pixel:</translation>
    </message>
    <message>
        <location filename="../fontconfigdialog.ui" line="90"/>
        <source>Antialiasing</source>
        <translation>Anti-aliasing</translation>
    </message>
    <message>
        <location filename="../fontconfigdialog.ui" line="97"/>
        <source>Hinting style:</source>
        <translation>Stile di hinting:</translation>
    </message>
    <message>
        <location filename="../fontconfigdialog.cpp" line="42"/>
        <location filename="../fontconfigdialog.cpp" line="47"/>
        <source>None</source>
        <translation>Nessuno</translation>
    </message>
    <message>
        <location filename="../fontconfigdialog.cpp" line="43"/>
        <source>Slight</source>
        <translation>Moderato</translation>
    </message>
    <message>
        <location filename="../fontconfigdialog.cpp" line="44"/>
        <source>Medium</source>
        <translation>Medio</translation>
    </message>
    <message>
        <location filename="../fontconfigdialog.cpp" line="45"/>
        <source>Full</source>
        <translation>Intero</translation>
    </message>
    <message>
        <location filename="../fontconfigdialog.cpp" line="74"/>
        <source>&lt;i&gt;%1&lt;/i&gt; already exists. Do you want to replace it?</source>
        <translation>&lt;i&gt;%1&lt;/i&gt; già esistente. Vuoi sostituirlo?</translation>
    </message>
</context>
<context>
    <name>FontsPage</name>
    <message>
        <location filename="../fontspage.ui" line="47"/>
        <location filename="../fontspage.ui" line="67"/>
        <location filename="../fontspage.ui" line="86"/>
        <location filename="../fontspage.ui" line="93"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../fontspage.ui" line="60"/>
        <source>General:</source>
        <translation>Generale:</translation>
    </message>
    <message>
        <location filename="../fontspage.ui" line="100"/>
        <source>Fixed width:</source>
        <translation>Larghezza fissa:</translation>
    </message>
    <message>
        <location filename="../fontspage.ui" line="125"/>
        <source>Create  fonts.conf</source>
        <translation>Crea  fonts.conf</translation>
    </message>
    <message>
        <location filename="../fontspage.ui" line="132"/>
        <source>Remove fonts.conf</source>
        <translation>Elimina fonts.conf</translation>
    </message>
    <message>
        <location filename="../fontspage.cpp" line="115"/>
        <source>Remove Font Configuration</source>
        <translation>Elimina la configurazione dei font</translation>
    </message>
    <message>
        <location filename="../fontspage.cpp" line="116"/>
        <source>Are you sure you want to delete &lt;i&gt;%1&lt;/i&gt;?</source>
        <translation>Sei sicuro di voler eliminare &lt;i&gt;%1&lt;/i&gt;?</translation>
    </message>
</context>
<context>
    <name>InterfacePage</name>
    <message>
        <location filename="../interfacepage.ui" line="35"/>
        <source>Double click interval:</source>
        <translation>Intervallo doppio clic:</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="42"/>
        <source>Cursor flash time:</source>
        <translation>Intervallo lampeggio cursore:</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="49"/>
        <source>ComboBox effect:</source>
        <translation>Effetto casella combinata:</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="56"/>
        <source>ToolTip effect:</source>
        <translation>Effetto suggerimento:</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="63"/>
        <source>ToolBox effect:</source>
        <translation>Effetto casella strumenti:</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="70"/>
        <location filename="../interfacepage.ui" line="80"/>
        <source> ms</source>
        <translation> ms</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="94"/>
        <location filename="../interfacepage.ui" line="111"/>
        <location filename="../interfacepage.ui" line="133"/>
        <location filename="../interfacepage.ui" line="157"/>
        <source>Disable</source>
        <translation>Disabilita</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="99"/>
        <location filename="../interfacepage.ui" line="116"/>
        <location filename="../interfacepage.ui" line="138"/>
        <location filename="../interfacepage.ui" line="162"/>
        <source>Animate</source>
        <translation>Animazione</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="121"/>
        <location filename="../interfacepage.ui" line="167"/>
        <source>Fade</source>
        <translation>Dissolvenza</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="146"/>
        <source>Menu effect:</source>
        <translation>Effetto menu:</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="175"/>
        <source>Enable gui effects</source>
        <translation>Abilita effetti interfaccia grafica</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="182"/>
        <source>Dialog buttons layout:</source>
        <translation>Disposizione pulsanti finestre dialogo:</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="192"/>
        <source>Menus have icons</source>
        <translation>Menu con icone</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="199"/>
        <source>Dialog buttons have icons</source>
        <translation>Pulsanti finestre dialogo con icone</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="209"/>
        <source>Activate item on single-click</source>
        <translation>Attiva oggetto con clic singolo</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="219"/>
        <source>Toolbar button style:</source>
        <translation>Stile pulsante barra strumenti:</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="229"/>
        <source>Mouse wheel scroll lines:</source>
        <translation>Linee scorrimento rotellina mouse:</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="246"/>
        <source>Show shortcut underlines</source>
        <translation>Mostra sottolineatura collegamenti</translation>
    </message>
    <message>
        <location filename="../interfacepage.cpp" line="47"/>
        <source>Only display the icon</source>
        <translation>Mostra solo l&apos;icona</translation>
    </message>
    <message>
        <location filename="../interfacepage.cpp" line="48"/>
        <source>Only display the text</source>
        <translation>Mostra solo il testo</translation>
    </message>
    <message>
        <location filename="../interfacepage.cpp" line="49"/>
        <source>The text appears beside the icon</source>
        <translation>Il testo appare accanto all&apos;icona</translation>
    </message>
    <message>
        <location filename="../interfacepage.cpp" line="50"/>
        <source>The text appears under the icon</source>
        <translation>Il testo appare sotto l&apos;icona</translation>
    </message>
    <message>
        <location filename="../interfacepage.cpp" line="51"/>
        <source>Follow the application style</source>
        <translation>Segui lo stile dell&apos;applicazione</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>Qt5 Configuration Tool</source>
        <translation>Strumento di configurazione Qt5</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="45"/>
        <source>Appearance</source>
        <translation>Aspetto</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="46"/>
        <source>Fonts</source>
        <translation>Caratteri</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="47"/>
        <source>Icon Theme</source>
        <translation>Tema icone</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="48"/>
        <source>Interface</source>
        <translation>Interfaccia</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="50"/>
        <source>Style Sheets</source>
        <translation>Fogli di stile</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="58"/>
        <source>Version: %1</source>
        <translation>Versione: %1</translation>
    </message>
</context>
<context>
    <name>PaletteEditDialog</name>
    <message>
        <location filename="../paletteeditdialog.ui" line="14"/>
        <source>Palette Editor</source>
        <translation>Editor colori</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.ui" line="79"/>
        <source>Reset palette</source>
        <translation>Azzera colori</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.ui" line="29"/>
        <source>Build inactive palette</source>
        <translation>Crea colori inattivi</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.ui" line="36"/>
        <source>Build disabled palette</source>
        <translation>Crea colori disabilitati</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="49"/>
        <source>Active</source>
        <translation>Attivo</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="49"/>
        <source>Inactive</source>
        <translation>Inattivo</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="49"/>
        <source>Disabled</source>
        <translation>Disabilitato</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="91"/>
        <source>Dark</source>
        <translation>Scuro</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="91"/>
        <source>Window text</source>
        <translation>Testo finestra</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="91"/>
        <source>Button background</source>
        <translation>Sfondo pulsante</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="91"/>
        <source>Bright</source>
        <translation>Chiaro</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="91"/>
        <source>Less bright</source>
        <translation>Meno chiaro</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="91"/>
        <source>Less dark</source>
        <translation>Meno scuro</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="92"/>
        <source>Window</source>
        <translation>Finestra</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="92"/>
        <source>Shadow</source>
        <translation>Ombreggiatura</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="92"/>
        <source>Bright text</source>
        <translation>Testo chiaro</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="92"/>
        <source>Button text</source>
        <translation>Testo pulsante</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="92"/>
        <source>Normal text</source>
        <translation>Testo normale</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="92"/>
        <source>Normal background</source>
        <translation>Sfondo normale</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="93"/>
        <source>Highlight</source>
        <translation>Evidenzia</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="93"/>
        <source>Highlighted text</source>
        <translation>Testo evidenziato</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="93"/>
        <source>Visited link</source>
        <translation>Collegamento visitato</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="94"/>
        <source>Default</source>
        <translation>Predefinito</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="94"/>
        <source>Tooltip background</source>
        <translation>Sfondo suggerimento</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="94"/>
        <source>Tooltip text</source>
        <translation>Testo suggerimento</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="93"/>
        <source>Link</source>
        <translation>Collegamento</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="94"/>
        <source>Alternate background</source>
        <translation>Sfondo alternativo</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="106"/>
        <source>Select Color</source>
        <translation>Seleziona colore</translation>
    </message>
</context>
<context>
    <name>PreviewForm</name>
    <message>
        <location filename="../previewform.ui" line="14"/>
        <source>Preview Window</source>
        <translation>Finestra di anteprima</translation>
    </message>
    <message>
        <location filename="../previewform.ui" line="24"/>
        <source>Tab 1</source>
        <translation>Linguetta 1</translation>
    </message>
    <message>
        <location filename="../previewform.ui" line="30"/>
        <source>PushButton</source>
        <translation>Pulsante</translation>
    </message>
    <message>
        <location filename="../previewform.ui" line="51"/>
        <source>Tab 2</source>
        <translation>Linguetta 2</translation>
    </message>
    <message>
        <location filename="../previewform.ui" line="57"/>
        <source>RadioButton</source>
        <translation>Pulsante a scelta singola</translation>
    </message>
    <message>
        <location filename="../previewform.ui" line="64"/>
        <source>CheckBox</source>
        <translation>Casella di spunta</translation>
    </message>
</context>
<context>
    <name>QSSEditorDialog</name>
    <message>
        <location filename="../qsseditordialog.cpp" line="46"/>
        <source>%1 - Style Sheet Editor</source>
        <translation>%1 - Editor fogli di stile</translation>
    </message>
    <message>
        <location filename="../qsseditordialog.ui" line="14"/>
        <source>Style Sheet Editor</source>
        <translation>Editor fogli di stile</translation>
    </message>
</context>
<context>
    <name>QSSPage</name>
    <message>
        <location filename="../qsspage.ui" line="23"/>
        <source>Create</source>
        <translation>Crea</translation>
    </message>
    <message>
        <location filename="../qsspage.ui" line="66"/>
        <location filename="../qsspage.cpp" line="51"/>
        <location filename="../qsspage.cpp" line="87"/>
        <source>Edit</source>
        <translation>Modifica</translation>
    </message>
    <message>
        <location filename="../qsspage.ui" line="76"/>
        <location filename="../qsspage.cpp" line="53"/>
        <source>Rename</source>
        <translation>Rinomina</translation>
    </message>
    <message>
        <location filename="../qsspage.ui" line="33"/>
        <location filename="../qsspage.cpp" line="55"/>
        <source>Remove</source>
        <translation>Rimuovi</translation>
    </message>
    <message>
        <location filename="../qsspage.cpp" line="52"/>
        <source>Create a Copy</source>
        <translation type="unfinished">Crea una copia</translation>
    </message>
    <message>
        <location filename="../qsspage.cpp" line="92"/>
        <source>View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qsspage.cpp" line="106"/>
        <location filename="../qsspage.cpp" line="251"/>
        <source>File name:</source>
        <translation>Nome file:</translation>
    </message>
    <message>
        <location filename="../qsspage.cpp" line="106"/>
        <location filename="../qsspage.cpp" line="251"/>
        <source>Enter Style Sheet Name</source>
        <translation>Inserisci nome del foglio di stile</translation>
    </message>
    <message>
        <location filename="../qsspage.cpp" line="117"/>
        <location filename="../qsspage.cpp" line="218"/>
        <location filename="../qsspage.cpp" line="226"/>
        <location filename="../qsspage.cpp" line="263"/>
        <location filename="../qsspage.cpp" line="271"/>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
    <message>
        <location filename="../qsspage.cpp" line="117"/>
        <source>The file &quot;%1&quot; already exists</source>
        <translation>Il file &quot;%1&quot; è già esistente</translation>
    </message>
    <message>
        <location filename="../qsspage.cpp" line="151"/>
        <source>Confirm Remove</source>
        <translation>Conferma rimozione</translation>
    </message>
    <message>
        <location filename="../qsspage.cpp" line="152"/>
        <source>Are you sure you want to remove style sheet &quot;%1&quot;?</source>
        <translation>Sei sicuro di voler rimuovere il foglio di stile &quot;%1&quot;?</translation>
    </message>
    <message>
        <location filename="../qsspage.cpp" line="208"/>
        <source>Rename Style Sheet</source>
        <translation>Rinomina il foglio di stile</translation>
    </message>
    <message>
        <location filename="../qsspage.cpp" line="208"/>
        <source>Style sheet name:</source>
        <translation>Nome del foglio di stile:</translation>
    </message>
    <message>
        <location filename="../qsspage.cpp" line="218"/>
        <location filename="../qsspage.cpp" line="263"/>
        <source>The style sheet &quot;%1&quot; already exists</source>
        <translation>Il foglio di stile &quot;%1&quot; è già esistente</translation>
    </message>
    <message>
        <location filename="../qsspage.cpp" line="226"/>
        <source>Unable to rename file</source>
        <translation>Impossibile rinominare file</translation>
    </message>
    <message>
        <location filename="../qsspage.cpp" line="253"/>
        <source>%1 (copy).qss</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qsspage.cpp" line="271"/>
        <source>Unable to copy file</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../main.cpp" line="62"/>
        <source>Please remove the &lt;b&gt;QT_STYLE_OVERRIDE&lt;/b&gt; environment variable</source>
        <translation>Rimuovi la variabile d&apos;ambiente &lt;b&gt;QT_STYLE_OVERRIDE&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="67"/>
        <source>The &lt;b&gt;QT_QPA_PLATFORMTHEME&lt;/b&gt; environment variable is not set correctly</source>
        <translation>La variabile d&apos;ambiente &lt;b&gt;QT_QPA_PLATFORMTHEME&lt;/b&gt; non è impostata correttamente</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="73"/>
        <source>Unable to find &lt;b&gt;libqt5ct-style.so&lt;/b&gt;</source>
        <translation>Impossibile trovare &lt;b&gt;libqt5ct-style.so&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="78"/>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
</context>
</TS>
